<?php
/*
 * Plugin Name: Popup Lightbox 
 * Plugin URI: http://wordpress.org/extend/plugins/popup-lightbox/ 
 * Requires at least: 3.2.1
 * Tested up to: 3.2.2 
 * Stable tag: 0.1.1
 * Description: Plugin creates a custom post to create popup on your homepage, popups can be configured such date of publication and date of expiration, may be placed video (Youtube), and image only.
 * Version: 0.1.1
 * Author: Ramon Vicente 
 * Author URI: http://ramonvic.com.br/ 
 * Contributors: Umobi Platform Free 
 * Link: http://wordpress.org/extend/plugins/popup-lightbox/ 
 * Tags: popup, popup lightbox, colorbox, lightbox, banner float, banner, popup scheduler 
 * License: GPLv3
 */

if (! defined('PLIGHTBOX_VERSION')) {
    define('PLIGHTBOX_VERSION', '0.1');
}
define('PLIGHTBOX_ABSPATH', dirname(__FILE__));
define('PLIGHTBOX_RELPATH', plugins_url() . '/' . basename(PLIGHTBOX_ABSPATH));

add_action('init', array('PopupLightbox', 'init'));

class PopupLightbox
{

    public static function init ()
    {
    	if (is_admin())
        	self::admin_init_hook();
    	else
    		self::frontend_init_hook();
    }
    
    public static function admin_init_hook(){
    	
    	self::register_post_type_popup();
    	
    	if (isset($_GET['insert-field-value']) || (isset($_SERVER['HTTP_REFERER']) && strpos($_SERVER['HTTP_REFERER'], 'insert-field-value=1'))){
    		// Add types button
    		add_filter('attachment_fields_to_edit', array('PopupLightbox', 'attachment_fields_to_edit'), 10, 2);
	        // Add JS
	        add_action('admin_head', array('PopupLightbox', 'attachment_admin_head'));
	        
    	}
    	
    	add_action( 'save_post', array('PopupLightbox', 'save_data') );
    	add_action ('admin_menu', array('PopupLightbox', 'add_submenu_sidebar'));
    	
    	add_filter('manage_edit-popup-lightbox_columns', array('PopupLightbox', 'add_columm_to_list'));
    	
    	add_action('manage_posts_custom_column', array('PopupLightbox', 'manage_posts_custom'));
    }
    
    public static function add_columm_to_list($columns){

        $columns = array(
                'cb' => '<input type="checkbox" />',
                'title' => __('Title'),
                'type' => __('Type'),
                'status' => __('Status'),
                'date' => __('Date')
            );
        
        return $columns;
    }
    
    public static function manage_posts_custom($column){
        global $post;
        $custom = get_post_custom($post->ID);
        $time = current_time('timestamp');
        switch ($column) {
            case 'status' :
                $status = $custom['popup_agendamento'][0] <= $time && $custom['popup_expirar'][0] >= $time ? __('Enabled') : __('Disabled');
                echo "<strong>{$status}</strong>";
            break;
            case 'type' :
                $type = $custom['popup_image'][0] ? __('Image') : __('Video');
                echo "<strong>{$type}</strong>";
            break;
        }
    }
    
    public static function frontend_init_hook(){
        add_action('wp_head', array('PopupLightbox', 'add_popup_script_frontend'), 1);
        add_action('wp_footer', array('PopupLightbox', 'add_popup_frontend'), 100);
    }
    
    public static function run_popup(){?>
        <script type="text/javascript">
            jQuery(window).load(function() {
                jQuery.colorbox({
                    html: jQuery('#popup').html(),
                    scalePhotos : false
                });
            });
        </script>
    <?php }
    
    public static function add_popup_frontend($a){
        global $wpdb, $query_string;
        wp_reset_query();
        if(!is_home() && !is_front_page())return;
        
        $time = current_time('timestamp');
        
        $query = array(
               'post_type' => 'popup-lightbox',
               'paged' => 1,
               'posts_per_page' => 1,
               'meta_query' => array(
                	array(
                		'key' => 'popup_agendamento',
                		'value' => $time,
                		'compare' => '<='
                	),
                	array(
                		'key' => 'popup_expirar',
                		'value' => $time,
                		'compare' => '>='
                	)
                )
           );
       $loop = new WP_Query($query);
       
       if ($loop->have_posts()){
           while ($loop->have_posts()) { $loop->the_post();
           $custom = get_post_custom();
           
           if($custom['popup_image'][0] || $custom['popup_video'][0]){
                self::run_popup();?>
            	<div id="popup" style="display: none;">
                    <?php if($custom['popup_image'][0]){?>
                        <img src="<?php echo $custom['popup_image'][0];?>" style="display: block" />
                    <?php }elseif($custom['popup_video'][0]){?>
                        <iframe style="display: block" width="853" height="480" src="http://www.youtube.com/embed/<?php self::extract_youtube_code();?>?wmode=transparent" frameborder="0" allowfullscreen></iframe>
                    <?php }?>
            </div>
            <?php }
            }
        }
    }
    
    public static function extract_youtube_code($id = 0, $display = true)
    {
        global $post;
        if (! $id)
            $id = $post->ID;
        $c = get_post_custom($id);
        $youtube_url = $c['popup_video'][0];
        if (preg_match("#^.*(youtu.be/|v/|/u/\w/|embed/|watch\?)\??v?=?(.{11}).*#", $youtube_url, $matches))
            if (strlen($matches[2]) == 11)
                if ($display)
                    echo $matches[2];
                else
                    return $matches[2];
     }
    
    public static function add_popup_script_frontend($a){
        wp_enqueue_script('popup-lightbox', PLIGHTBOX_RELPATH . '/js/jquery.colorbox-min.js', array('jquery'), PLIGHTBOX_VERSION);
        wp_enqueue_style('popup-lightbox', PLIGHTBOX_RELPATH . '/css/colorbox.css', false, PLIGHTBOX_VERSION);
    }
    
    public static function save_data($post_id){
    	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
    		return;
    	$data = $_POST['pl'] ? $_POST['pl'] : array();
    	
    	foreach ($data as $k => $v){
    		if (preg_match('#^(\d{2})\/(\d{2})\/(\d{4})\s(\d{2})\:(\d{2})$#', $v, $m))
    			$v = mktime($m[4],$m[5],0,$m[2],$m[1],$m[3]);
    		
    		update_post_meta($post_id, 'popup_'.$k, $v, get_post_meta($post_id, 'popup_'.$k, TRUE));
    	}
    	
    	return $data;
    }

    public static function register_post_type_popup ()
    {
        $labels = array(
        		'name' => __('Popup', 'post type general name'), 
        		'singular_name' => __('Popup', 'post type singular name'), 
        		'add_new' => __('Add New', 'book'), 
        		'add_new_item' => __('Add New Popup'), 
        		'edit_item' => __('Edit Popup'), 
        		'new_item' => __('New Popup'), 
        		'all_items' => __('All Popups'), 
        		'view_item' => __('View Popup'), 
        		'search_items' => __('Search Popups'), 
        		'not_found' => __('No Popups found'), 
        		'not_found_in_trash' => __('No Popups found in Trash'), 
        		'parent_item_colon' => '', 
        		'menu_name' => 'Popup'
        	);
        
        $args = array(
        		'labels' => $labels, 
        		'public' => false, 
        		'publicly_queryable' => false, 
        		'show_ui' => true, 
        		'show_in_menu' => true, 
        		'capability_type' => 'post', 
        		'has_archive' => true, 
        		'hierarchical' => false, 
        		'menu_position' => 25, 
        		'menu_item' => 50,
        		'menu_icon' => PLIGHTBOX_RELPATH . "/images/calendar.gif",
        		'map_meta_cap' => true, 
        		'supports' => array('title'), 
        		'register_meta_box_cb' => 'PopupLightbox::register_meta_boxes'
        	);
        
        register_post_type('popup-lightbox', $args);
        
    
    }
    
    public static function add_submenu_sidebar(){
        add_submenu_page( 'edit.php?post_type=popup-lightbox', __('About Popup Lightbox'), __('About'), 'publish_posts', 'popup-lightbox-about', array('PopupLightbox', 'about') ); 
    }

    public static function register_meta_boxes ()
    {
        add_meta_box('popup-data', __('Popup Data'), array('PopupLightbox', 'meta_box_display'), 'popup-lightbox', 'normal');
    }

    public static function meta_box_display ()
    {
        global $post;
        $custom = get_post_custom($post->ID);
        add_thickbox();
        wp_enqueue_script('jquery-ui-datepicker');
        wp_enqueue_script('jquery-ui-slider');
        wp_enqueue_script('wpcf-form-validation', PLIGHTBOX_RELPATH . '/js/jquery.validate.min.js', array('jquery'));
        wp_enqueue_script('wpcf-form-validation-additional', PLIGHTBOX_RELPATH . '/js/additional-methods.min.js', array('jquery'));
        wp_enqueue_script('jquery-ui-timedatepicker', PLIGHTBOX_RELPATH . '/js/jquery-ui-timepicker-addon.js', array('jquery'));
		
        wp_enqueue_style('jquery-ui-datepicker', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.6/themes/smoothness/jquery-ui.css');
        wp_enqueue_style('popup-lightbox', PLIGHTBOX_RELPATH . '/css/style.css');
        
        $data = $custom['popup_expirar'][0];
        
        $custom['popup_agendamento'] = date('d/m/Y H:i', $custom['popup_agendamento'][0]);
        $custom['popup_expirar'] = date('d/m/Y H:i', $custom['popup_expirar'][0]);
        
        include_once PLIGHTBOX_ABSPATH . '/includes/meta-box.php';
    }
    
    public static function attachment_fields_to_edit($form_fields, $post) {
	    $type = (strpos($post->post_mime_type, 'image/') !== false) ? 'image' : 'file';
	    $form_fields['wpcf_fields_file'] = array(
	        'label' => __('Popup'),
	        'input' => 'html',
	        'html' => '<a href="#" title="' . $post->guid . '" class="button-primary" onclick="addFiletoField(\'' . $post->guid . '\', \'' . $type . '\')">' . __('Use as field value') . '</a><br /><br />',
	    );
	    return $form_fields;
    }
    
    public static function attachment_admin_head(){ ?>
    	<script type="text/javascript">
    	    function addFiletoField(guid, type) {
    	        window.parent.addFiletoField(guid, type);
    	        window.parent.jQuery('#TB_closeWindowButton').trigger('click');
    	    }
    	</script><?php
    }
	public static function about(){
		
	}
	
    static function getInstance ()
    {
        if (null === self::$_instance)
            self::$_instance = new self();
        return self::$_instance;
    }
}